summaryrefslogtreecommitdiffstats
path: root/src/usr/initservice/istepdispatcher/istepdispatcher.C
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr/initservice/istepdispatcher/istepdispatcher.C')
-rw-r--r--src/usr/initservice/istepdispatcher/istepdispatcher.C15
1 files changed, 11 insertions, 4 deletions
diff --git a/src/usr/initservice/istepdispatcher/istepdispatcher.C b/src/usr/initservice/istepdispatcher/istepdispatcher.C
index eaac5b902..7197dc8d2 100644
--- a/src/usr/initservice/istepdispatcher/istepdispatcher.C
+++ b/src/usr/initservice/istepdispatcher/istepdispatcher.C
@@ -177,9 +177,10 @@ void IStepDispatcher::init ( errlHndl_t &io_rtaskRetErrl )
do
{
- if( !spLess() )
+ if( MBOX::mailbox_enabled() )
{
// register message Q with FSP Mailbox - only if Fsp attached.
err = MBOX::msgq_register( MBOX::HB_ISTEP_MSGQ,
iv_msgQ );
@@ -188,6 +189,12 @@ void IStepDispatcher::init ( errlHndl_t &io_rtaskRetErrl )
break;
}
}
+ else
+ {
+ assert(spLess()); // If the mailbox is disabled, we better be in
+ // spLess mode. Otherwise, attributes are set
+ // incorrectly.
+ }
// Spawn off the Worker thread
tid_t l_workerTid = task_create( startIStepWorkerThread,
@@ -233,7 +240,7 @@ void IStepDispatcher::init ( errlHndl_t &io_rtaskRetErrl )
TRACFCOMP( g_trac_initsvc,
"IStep run all" );
- if(!spLess())
+ if(MBOX::mailbox_enabled())
{
// Read the attribute indicating if the FSP has overrides
// and get the overrides if it does
@@ -915,7 +922,7 @@ void IStepDispatcher::handleBreakpoint ( uint32_t i_info )
myMsg->data[1] = 0x0;
myMsg->extra_data = NULL;
- if( !spLess() )
+ if( MBOX::mailbox_enabled() )
{
// FSP Attached
// Wait for Fsp to respond.
@@ -177,9 +177,10 @@ void IStepDispatcher::init ( errlHndl_t &io_rtaskRetErrl )
{
- // register message Q with FSP Mailbox - only if Fsp attached.
+ // register message Q with FSP Mailbox - only if mailbox
+ // enabled
err = MBOX::msgq_register( MBOX::HB_ISTEP_MSGQ,
iv_msgQ );
OpenPOWER on IntegriCloud